@@ -7,11 +7,11 @@ from jft.directory.make import f as mkdir
 
 def f(root, filepaths=[], condition=lambda x: True):
   for item in listdir(root):
-    π = root+'/'+item
-    if isdir(π):
-      f(π, filepaths, condition)
+    _pi = root+'/'+item
+    if isdir(_pi):
+      f(_pi, filepaths, condition)
     if condition(item):
-      filepaths.append(π)
+      filepaths.append(_pi)
   return filepaths
 
 temp_dir_0 = './_list_filepaths'
