@@ -1,4 +1,4 @@
-f = lambda Λ_a, Λ_b: Λ_a + [λ_b for λ_b in Λ_b if λ_b not in set(Λ_a)]
+f = lambda _L_a, _L_b: _L_a + [_l_b for _l_b in _L_b if _l_b not in set(_L_a)]
 t = lambda: all([
   [] == f([], []),
   list('abcdef') == f(list('abc'), list('def')),
