@@ -1,8 +1,8 @@
 from jft.text_colours.info import f as info
 from jft.string.hbar.make import f as hbar
 
-f = lambda π_filename, function_text: '\n'.join([
-  info(f'{π_filename} function_text:'),
+f = lambda _pi_filename, function_text: '\n'.join([
+  info(f'{_pi_filename} function_text:'),
   function_text,
   hbar(),
 ])
