@@ -12,11 +12,11 @@ _failed_pickle_path = f'{_dir}/failed.pickle'
 def setup(): mkdirine(_dir)
 def tear_down(): rmdirie(_dir)
 
-def f(Π_failed, π, message, dt_now=None, root='.'):
+def f(_Pi_failed, _pi, message, dt_now=None, root='.'):
   dt_now = dt_now or dt.now()
-  Π_failed.add(π)
-  save(Π_failed, f'{root}/failed.pickle')
-  return False, f"{danger('FAIL')} {warn(π)} {message} {dt_now}"
+  _Pi_failed.add(_pi)
+  save(_Pi_failed, f'{root}/failed.pickle')
+  return False, f"{danger('FAIL')} {warn(_pi)} {message} {dt_now}"
 
 def t():
   setup()
